//+------------------------------------------------------------------+
//|                                                  Check_Money.mq5 |
//|                        Copyright 2010, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2010, MetaQuotes Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"

#property script_show_inputs
input double          lots=1.0;            // number of lots
input ENUM_ORDER_TYPE type=ORDER_TYPE_BUY;
//+------------------------------------------------------------------+
//| Script program start function                                    |
//+------------------------------------------------------------------+
void OnStart()
  {
//--- variable for receiving the margin value
   double margin;
//--- to get the information of the last tick
   MqlTick last_tick;
//--- try to get the values of the last tick
   if(SymbolInfoTick(Symbol(),last_tick))
     {
      //--- reset the last error code
      ResetLastError();
      //--- calculate the margin value
      bool check=OrderCalcMargin(type,Symbol(),lots,last_tick.ask,margin);
      if(check)
        {
         PrintFormat("For the operation %s  %s %.2f lot at %G you need %.2f %s",OrderTypeToString(type),
                     Symbol(),lots,last_tick.ask,margin,AccountInfoString(ACCOUNT_CURRENCY));
        }
     }
   else
     {
      Print("Unsuccessful execution of the SymbolInfoTick() function, error ",GetLastError());
     }

//--- show the message about free assets
   PrintFormat("Amount of free margin: %G %s",AccountInfoDouble(ACCOUNT_FREEMARGIN),AccountInfoString(ACCOUNT_CURRENCY));

//--- calculate the rates of margin charging for different types of orders
   PrintFormat("Rate of margin charging on long positions is equal to %G",SymbolInfoDouble(Symbol(),SYMBOL_MARGIN_LONG));
   PrintFormat("Rate of margin charging on short positions is equal to %G",SymbolInfoDouble(Symbol(),SYMBOL_MARGIN_SHORT));
   PrintFormat("Rate of margin charging on Limit orders is equal to %G",SymbolInfoDouble(Symbol(),SYMBOL_MARGIN_LIMIT));
   PrintFormat("Rate of margin charging on Stop orders is equal to %G",SymbolInfoDouble(Symbol(),SYMBOL_MARGIN_STOP));
   PrintFormat("Rate of margin charging on Stop Limit orders is equal to %G",SymbolInfoDouble(Symbol(),SYMBOL_MARGIN_STOPLIMIT));

  }
//+------------------------------------------------------------------+
//| returns the string representation of the type of an order        |
//+------------------------------------------------------------------+
string OrderTypeToString(ENUM_ORDER_TYPE t)
  {
   switch(t)
     {
      case ORDER_TYPE_BUY:            return "buy";
      case ORDER_TYPE_SELL:           return "sell";
      case ORDER_TYPE_BUY_LIMIT:      return "buy limit";
      case ORDER_TYPE_SELL_LIMIT:     return "sell limit";
      case ORDER_TYPE_BUY_STOP:       return "buy stop";
      case ORDER_TYPE_SELL_STOP:      return "sell stop";
      case ORDER_TYPE_BUY_STOP_LIMIT: return "buy stop limit";
      case ORDER_TYPE_SELL_STOP_LIMIT:return "sell stop limit";
      default:                        return "unknown type of order";
     }
   return "";
  }
//+------------------------------------------------------------------+
